@@ -1,4 +1,4 @@
-/* Copyright (C) 2011, 2013 D. V. Wiebe
+/* Copyright (C) 2011, 2013, 2016, 2017 D.V. Wiebe
  *
  ***************************************************************************
  *
@@ -25,21 +25,14 @@ int main(void)
   const char *filedir = "dirfile";
   const char *format = "dirfile/format";
   const char *format1 = "dirfile/format1";
-  const char *format_data = "/INCLUDE format1 A Z\n";
-  const char *format1_data = "data RAW UINT8 8\n";
-  int fd, ret, e1, r = 0;
+  int ret, e1, r = 0;
   DIRFILE *D;
 
   rmdirfile();
-  mkdir(filedir, 0777);
+  mkdir(filedir, 0700);
 
-  fd = open(format, O_CREAT | O_EXCL | O_WRONLY, 0666);
-  write(fd, format_data, strlen(format_data));
-  close(fd);
-
-  fd = open(format1, O_CREAT | O_EXCL | O_WRONLY, 0666);
-  write(fd, format1_data, strlen(format1_data));
-  close(fd);
+  MAKEFORMATFILE(format, "/INCLUDE format1 A Z\n");
+  MAKEFORMATFILE(format1, "data RAW UINT8 8\n");
 
   D = gd_open(filedir, GD_RDWR);
   ret = gd_rename(D, "AdataZ", "zata", 0);
@@ -52,7 +45,7 @@ int main(void)
   rmdir(filedir);
 
   CHECKI(e1,GD_E_BAD_CODE);
-  CHECKI(ret,-1);
+  CHECKI(ret,GD_E_BAD_CODE);
 
   return r;
 }
